# $NetBSD: builtin.mk,v 1.2 2022/12/04 15:35:27 wiz Exp $

BUILTIN_PKG:=	xinit

BUILTIN_FIND_FILES_VAR:=	XINIT
BUILTIN_FIND_FILES.XINIT=	${X11BASE}/bin/xinit

.include "../../mk/buildlink3/bsd.builtin.mk"

###
### Determine if there is a built-in implementation of the package and
### set IS_BUILTIN.<pkg> appropriately ("yes" or "no").
###
.if !defined(IS_BUILTIN.xinit)
.  if empty(XINIT:M__nonexistent__)
IS_BUILTIN.xinit=	yes
.  else
IS_BUILTIN.xinit=	no
.  endif
.endif
MAKEVARS+=		IS_BUILTIN.xinit

###
### If there is a built-in implementation, then set BUILTIN_PKG.<pkg> to
### a package name to represent the built-in package.
###
.if !defined(BUILTIN_PKG.xinit) && \
    ${IS_BUILTIN.xinit:tl} == yes && \
    empty(XINIT:M__nonexistent__)

# we're more worried about existence, rather than actual version
BUILTIN_VERSION.xinit=	11.7

BUILTIN_PKG.xinit=	xinit-${BUILTIN_VERSION.xinit}
.endif
MAKEVARS+=		BUILTIN_PKG.xinit

###
### Determine whether we should use the built-in implementation if it
### exists, and set USE_BUILTIN.<pkg> appropriate ("yes" or "no").
###
.if !defined(USE_BUILTIN.xinit)
.  if ${PREFER.xinit} == "pkgsrc"
USE_BUILTIN.xinit=	no
.  else
USE_BUILTIN.xinit=	${IS_BUILTIN.xinit}
.    if defined(BUILTIN_PKG.xinit) && \
        ${IS_BUILTIN.xinit:tl} == yes
USE_BUILTIN.xinit=	yes
.      for _dep_ in ${BUILDLINK_API_DEPENDS.xinit}
.        if ${USE_BUILTIN.xinit:tl} == yes
USE_BUILTIN.xinit!=							\
	if ${PKG_ADMIN} pmatch ${_dep_:Q} ${BUILTIN_PKG.xinit:Q}; then \
		${ECHO} yes;						\
	else								\
		${ECHO} no;						\
	fi
.        endif
.      endfor
.    endif
.  endif  # PREFER.xinit
.endif

# Now set up the appropriate prefix for xinit
.if ${USE_BUILTIN.xinit:tl} == yes
XINITBASE=		${X11BASE}
.else
XINITBASE=		${PREFIX}
.endif
